summarysplitprocessor

package module
v0.0.0-...-d8446ed Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

README

summarysplitprocessor

This processor is used to convert from an older compatibility Open Telemetry format for metric data into something closer to a modern format. Cardinal uses This to convert data coming in from some receivers, such as the awsfirehose receiver, into standard metric data. Removing this "summary" format in this way allows processing standard histograms and data points instead.

Configuration

extensions:
  summarysplitprocessor:

No configuration is needed.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() processor.Factory

Types

type Config

type Config struct{}

func (*Config) Validate

func (c *Config) Validate() error

Directories

Path Synopsis
internal

Jump to