githubeventsreceiver

package module
v0.0.0-...-9c5bba4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: Apache-2.0 Imports: 19 Imported by: 0

README

githubeventsreceiver

This receiver obtains github events and converts them into log items. This is different than the community contrib github metrics processor, which is more tracking of data on the number of open issues. This receiver is intended to convert actions like a pull request was opened into an OTEL event that can be processed as part of the event/log processing pipeline.

Events are sent from Github via a web hook.

Configuration

receivers:
  githubevents:
    endpoint: 0.0.0.0:19418
    secret: "${env:GITHUB_SECRET}"
    path: /events

The endpoint defaults to external access on port 19418.

The path is where the github webhook should send events, and each event is validated with the provided secret before accepting it.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() receiver.Factory

Types

type Config

type Config struct {
	confighttp.ServerConfig `mapstructure:",squash"`
	Path                    string `mapstructure:"path"`        // path where the receiver instance will accept events. Default is /events
	Secret                  string `mapstructure:"secret"`      // secret to verify that a webhook delivery is from GitHub.
	HealthPath              string `mapstructure:"health_path"` // path for health check api. Default is /health_check
}

func (*Config) Validate

func (cfg *Config) Validate() error

Directories

Path Synopsis
internal

Jump to