Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
Types ¶
type CHQTagcacheExtension ¶
type CHQTagcacheExtension struct {
// contains filtered or unexported fields
}
func (*CHQTagcacheExtension) FetchCache ¶
func (chq *CHQTagcacheExtension) FetchCache(key string) ([]Tag, error)
FetchCache fetches the tags from the cache. This is intended to be called by the users of the extension.
func (*CHQTagcacheExtension) PutCache ¶
func (chq *CHQTagcacheExtension) PutCache(key string, tags []Tag) error
PutCache puts the tags in the cache. This is intended to be called by the users of the extension.
type Config ¶
type Config struct {
confighttp.ClientConfig `mapstructure:",squash"`
TTL time.Duration `mapstructure:"ttl"`
ErrorTTL time.Duration `mapstructure:"error_ttl"`
}
type TagsMessage ¶
type TagsMessage struct {
Tags []Tag `json:"tags"`
}
Click to show internal directories.
Click to hide internal directories.